@@ -244,10 +244,10 @@ def track_2d_all(config):
     calib_folder_name = config.get('project').get('calib_folder_name')
     poseTracked_folder_name = config.get('project').get('poseTracked_folder_name')
     pose_folder_name = config.get('project').get('pose_folder_name')
-    openpose_model = config.get('pose-2d').get('openpose_model')
+    pose_model = config.get('pose-2d').get('pose_model')
     tracked_keypoint = config.get('2d-tracking').get('tracked_keypoint')
     json_folder_extension =  config.get('project').get('pose_json_folder_extension')
-    frames_range = config.get('project').get('frames_range')
+    frame_range = config.get('project').get('frame_range')
     
     calib_dir = os.path.join(project_dir, calib_folder_name)
     calib_file = glob.glob(os.path.join(calib_dir, '*.toml'))[0]
@@ -258,7 +258,7 @@ def track_2d_all(config):
     P = computeP(calib_file)
     
     # selection of tracked keypoint id
-    model = eval(openpose_model)
+    model = eval(pose_model)
     tracked_keypoint_id = [node.id for _, _, node in RenderTree(model) if node.name==tracked_keypoint][0]
     
     # 2d-pose files selection
@@ -276,7 +276,7 @@ def track_2d_all(config):
     json_tracked_files = [[os.path.join(poseTracked_dir, j_dir, j_file) for j_file in json_files_names[j]] for j, j_dir in enumerate(json_dirs_names)]
     
     # person's tracking
-    f_range = [[min([len(j) for j in json_files])] if frames_range==[] else frames_range][0]
+    f_range = [[min([len(j) for j in json_files])] if frame_range==[] else frame_range][0]
     n_cams = len(json_dirs_names)
     error_min_tot, cameras_off_tot = [], []
     
